@@ -1,7 +1,9 @@
+# check_module
+from ..utils.__import_check import check_modules
+
 # Pandas related helper functions and dummies
 from .dataframe import (
     update_a_df_column,
-    pngTable,
     compare_two_df,
     add_a_col_from_a_df,
     search,
@@ -11,17 +13,12 @@ from .dataframe import (
     search_in_multiindex,
 )
 
-from .dummy import Dummy as __Dummy
-
-dummy = __Dummy()
-
+# Pareto ranking
 from .pareto_ranking import ParetoRanking as __ParetoRanking
-
 paretoranking = __ParetoRanking
 
 __all__ = [
     "update_a_df_column",
-    "pngTable",
     "compare_two_df",
     "add_a_col_from_a_df",
     "search",
@@ -29,6 +26,16 @@ __all__ = [
     "col",
     "uni",
     "search_in_multiindex",
-    "dummy",
     "paretoranking",
 ]
+
+# faker - dummy data
+if check_modules("faker"):
+    from .dummy import Dummy as __Dummy
+    dummy = __Dummy()
+    __all__ += ["dummy"]
+
+
+
+
+
